@@ -3,12 +3,10 @@ pub mod build;
 pub mod clean;
 pub mod completions;
 pub mod deploy;
-pub mod explorer;
-pub mod format;
 pub mod init;
 pub mod json_abi;
-pub mod lsp;
 pub mod parse_bytecode;
+pub mod plugins;
 pub mod run;
 pub mod test;
 pub mod update;
