@@ -1,9 +1,26 @@
-use crate::cli::{BuildCommand, JsonAbiCommand};
+use crate::{
+    cli::{BuildCommand, JsonAbiCommand},
+    utils::SWAY_GIT_TAG,
+};
 use anyhow::Result;
+use forc_pkg::{check_program_type, manifest_file_missing, Manifest};
+use forc_util::find_manifest_dir;
 use serde_json::{json, Value};
 use std::fs::File;
+use std::path::PathBuf;
+use sway_core::TreeType;
 
 pub fn build(command: JsonAbiCommand) -> Result<Value> {
+    let curr_dir = if let Some(ref path) = command.path {
+        PathBuf::from(path)
+    } else {
+        std::env::current_dir()?
+    };
+    let manifest_dir =
+        find_manifest_dir(&curr_dir).ok_or_else(|| manifest_file_missing(curr_dir))?;
+    let manifest = Manifest::from_dir(&manifest_dir, SWAY_GIT_TAG)?;
+    check_program_type(&manifest, manifest_dir, TreeType::Contract)?;
+
     let build_command = BuildCommand {
         path: command.path,
         offline_mode: command.offline_mode,
@@ -11,8 +28,10 @@ pub fn build(command: JsonAbiCommand) -> Result<Value> {
         minify_json_abi: command.minify,
         ..Default::default()
     };
+
     let compiled = crate::ops::forc_build::build(build_command)?;
     let json_abi = json!(compiled.json_abi);
+
     if let Some(outfile) = command.json_outfile {
         let file = File::create(outfile).map_err(|e| e)?;
         let res = if command.minify {
@@ -22,9 +41,10 @@ pub fn build(command: JsonAbiCommand) -> Result<Value> {
         };
         res.map_err(|e| e)?;
     } else if command.minify {
-        println!("{}", json_abi);
+        println!("{json_abi}");
     } else {
         println!("{:#}", json_abi);
     }
+
     Ok(json_abi)
 }
