@@ -11,7 +11,7 @@ license = "Apache-2.0"
 name = "{project_name}"
 
 [dependencies]
-std = {{ git = "https://github.com/FuelLabs/sway-lib-std", branch = "master" }}
+std = {{ git = "https://github.com/FuelLabs/sway", branch = "master" }}
 "#
     )
 }
